const path = require('path');
const webpack = require('webpack');
const ExtractTextPlugin = require('extract-text-webpack-plugin');


const config = {
    entry: {
        index: "./src/index.js"
    },
    output: {
        path: path.resolve(__dirname, "site"),
        filename: "[name].js"
    },
    resolve: {
        extensions: [".js", ".json", ".jsx", ".css"],
    },
    module: {

    },
    module: {
        rules: [
            {
                test: /\.jsx?$/,
                include: [
                    path.resolve(__dirname, "src")
                ],
                use: ['babel-loader']
            },
             {
                test: /\.css$/,
                use: ExtractTextPlugin.extract({ fallback: 'style-loader', use: 'css-loader' })
            },
            {
               test: /\.less$/,
               use: ExtractTextPlugin.extract(
                   // activate source maps via loader query
                   'css-loader?sourceMap!' +
                   'less-loader?sourceMap'
               )
            }
        ],
    },
    
    devtool: "source-map", 

    devServer: {
        // proxy: { // proxy URLs to backend development server
        //     '/api': 'http://localhost:3000'
        // },
        host: "0.0.0.0",
        port: 9000,
        contentBase: path.join(__dirname, 'site'), // boolean | string | array, static file location
        compress: true, // enable gzip compression
        historyApiFallback: true, // true for index.html upon 404, object for multiple paths
        hot: true, // hot module replacement. Depends on HotModuleReplacementPlugin
        https: false, // true for self-signed, object for cert authority
        noInfo: true, // only errors & warns on hot reload
        publicPath: '/'
    // ...
  },

  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new webpack.DefinePlugin({
        'process.env.NODE_ENV': '"production"',
    }),
    new ExtractTextPlugin({ filename: '[name].css', disable: false, allChunks: true })
  ]

}

module.exports = config;